@@ -6,6 +6,8 @@ use crate::pushover::constants;
 use super::PushoverSound;
 use super::AttachmentMessage;
 
+// TODO: Fix DRY principle with message_builder.rs
+
 /**
 Helps build a correct Pushover request, with attachment.
  */
@@ -121,6 +123,8 @@ impl AttachmentMessageBuilder {
     }
 
     /// Add a device name to send the notification to.
+    /// 
+    /// Ignores if the device name is already in the list.
     pub fn add_device(mut self, device_name: &str) -> AttachmentMessageBuilder {
         type Devices = Vec<String>;
 
@@ -130,6 +134,11 @@ impl AttachmentMessageBuilder {
 
         if self.build.devices.is_none() {
             self.build.devices = Some(vec!());
+        } else {
+            let clone: Vec<String> = self.build.devices.clone().unwrap();
+            if clone.contains(&device_name.into()) {
+                return self;
+            }
         }
 
         let mut replacement_list: Devices = self.build.devices.clone().unwrap();
@@ -139,6 +148,21 @@ impl AttachmentMessageBuilder {
         self
     }
 
+    /// Overrides the current devices list with device_names
+    pub fn set_devices(mut self, device_names: Vec<&str>) -> AttachmentMessageBuilder {
+        let device_names = device_names.iter().map(|x| x.to_string()).collect::<Vec<String>>();
+        self.build.devices = Some(device_names);
+        self
+    }
+
+    /// Merges the current devices list with device_names, duplicates are eliminated
+    pub fn merge_devices(mut self, device_names: Vec<&str>) -> AttachmentMessageBuilder {
+        for name in device_names {
+            self = self.add_device(name);
+        }
+        self
+    }
+
     pub fn clear_devices_list(mut self) -> AttachmentMessageBuilder {
         self.build.devices = None;
         self
